==> ngx-forkable-http-client-0.0.1.tgz: package/bundles/ngx-forkable-http-client.js <==
import { Inject, Injectable, NgModule, Optional } from '@angular/core';
import { HTTP_INTERCEPTORS, HttpBackend, HttpClient, HttpClientModule } from '@angular/common/http';

function createInterceptorHandler(baseHandler, interceptors) {
    return interceptors.reduceRight((next, interceptor) => new HttpInterceptorHandler(next, interceptor), baseHandler);
}
class HttpInterceptorHandler {
    constructor(next, interceptor) {
        this.next = next;
        this.interceptor = interceptor;
    }
    handle(request) {
        return this.interceptor.intercept(request, this.next);
    }
}

class ForkableHttpClient extends HttpClient {
    constructor(backend, interceptors) {
        super(createInterceptorHandler(backend, interceptors || []));
        this.backend = backend;
        this.interceptors = interceptors;
    }
    fork(...interceptors) {
        return new ForkableHttpClient(this.backend, [...this.interceptors, ...interceptors]);
    }
}
ForkableHttpClient.decorators = [
    { type: Injectable },
];
/** @nocollapse */
ForkableHttpClient.ctorParameters = () => [
    { type: HttpBackend, },
    { type: Array, decorators: [{ type: Optional }, { type: Inject, args: [HTTP_INTERCEPTORS,] },] },
];
function forkHttpClient(parent, ...interceptors) {
    return parent.fork(...interceptors);
}

class ForkableHttpClientModule {
}
ForkableHttpClientModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    HttpClientModule
                ],
                providers: [
                    ForkableHttpClient
                ]
            },] },
];
/** @nocollapse */
ForkableHttpClientModule.ctorParameters = () => [];

export { ForkableHttpClientModule, ForkableHttpClient, forkHttpClient, createInterceptorHandler, HttpInterceptorHandler };

==> ngx-forkable-http-client-0.1.0.tgz: package/bundles/ngx-forkable-http-client.js <==
import { Inject, Injectable, NgModule, Optional } from '@angular/core';
import { HTTP_INTERCEPTORS, HttpBackend, HttpClient, HttpClientModule, HttpHandler } from '@angular/common/http';

function createInterceptorHandler(baseHandler, interceptors) {
    return interceptors.reduceRight((next, interceptor) => new HttpInterceptorHandler(next, interceptor), baseHandler);
}
class HttpInterceptorHandler {
    constructor(next, interceptor) {
        this.next = next;
        this.interceptor = interceptor;
    }
    handle(request) {
        return this.interceptor.intercept(request, this.next);
    }
}

class ForkableHttpClient extends HttpClient {
    constructor(baseHandler, interceptors) {
        super(createInterceptorHandler(baseHandler, interceptors || []));
        this.baseHandler = baseHandler;
        this.interceptors = interceptors;
    }
    fork(...interceptors) {
        return new ForkableHttpClient(this.baseHandler, [...this.interceptors, ...interceptors]);
    }
}
ForkableHttpClient.decorators = [
    { type: Injectable },
];
/** @nocollapse */
ForkableHttpClient.ctorParameters = () => [
    { type: HttpHandler, decorators: [{ type: Inject, args: [HttpBackend,] },] },
    { type: Array, decorators: [{ type: Optional }, { type: Inject, args: [HTTP_INTERCEPTORS,] },] },
];
function forkHttpClient(parent, ...interceptors) {
    return parent.fork(...interceptors);
}

class ForkableHttpClientModule {
}
ForkableHttpClientModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    HttpClientModule
                ],
                providers: [
                    ForkableHttpClient
                ]
            },] },
];
/** @nocollapse */
ForkableHttpClientModule.ctorParameters = () => [];

export { ForkableHttpClientModule, ForkableHttpClient, forkHttpClient, createInterceptorHandler, HttpInterceptorHandler };
